Here is a brief description of the files included in this directory:
---

- [zsh_completion][1] - a Z Shell completion script, install (with a rename) to
`/usr/share/zsh/site-functions/`.

[1]: https://github.com/felixonmars/ydcv/blob/master/contrib/zsh_completion
